NuRadioReco\.modules\.io\.snowshovel package
============================================

Submodules
----------

NuRadioReco\.modules\.io\.snowshovel\.readARIANNAData module
------------------------------------------------------------

.. automodule:: NuRadioReco.modules.io.snowshovel.readARIANNAData
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco\.modules\.io\.snowshovel\.readARIANNADataCalib module
-----------------------------------------------------------------

.. automodule:: NuRadioReco.modules.io.snowshovel.readARIANNADataCalib
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: NuRadioReco.modules.io.snowshovel
    :members:
    :undoc-members:
    :show-inheritance:
